{ pkgs }:

with pkgs;
[
  # Nix
  nixd
  # General packages for development and system management
  #alacritty
  aspell
  aspellDicts.en
  bash-completion
  bat
  btop
  coreutils
  killall
  neofetch
  openssh
  sqlite
  wget
  zip
  htop
  ncdu
  mtr
  nixfmt-rfc-style
  difftastic
  # Development
  autoconf
  autoconf-archive
  automake
  ccache
  cmake
  nasm
  ninja
  pkg-config
  llvm
  clang-tools
  dfu-util
  # Encryption and security tools
  age
  sops
  gnupg
  libfido2

  # Cloud-related tools and SDKs
  docker
  docker-compose

  # Media-related packages
  emacs-all-the-icons-fonts
  dejavu_fonts
  ffmpeg
  fd
  font-awesome
  hack-font
  noto-fonts
  noto-fonts-emoji
  meslo-lgs-nf

  # Node.js development tools
  nodePackages.npm # globally install npm
  nodePackages.prettier
  nodejs

  # Text and terminal utilities
  htop
  hunspell
  iftop
  jetbrains-mono
  jq
  ripgrep
  tree
  tmux
  unrar
  unzip
  rmapi
  #  zsh-powerlevel10k

  # Python packages
  python3
  virtualenv

  # Rust Related
  rustc
  cargo

  # vscode see https://nixos.wiki/wiki/Visual_Studio_Code

  (vscode-with-extensions.override {
    vscodeExtensions =
      with vscode-extensions;
      [
        #bbenoist.nix
        jnoortheen.nix-ide
        ms-python.python
        ms-azuretools.vscode-docker
        #        ms-vscode-remote.remote-ssh
        # ms-vscode.cpptools
        eamodio.gitlens
      ]
      ++ pkgs.vscode-utils.extensionsFromVscodeMarketplace [
        #        {
        #          name = "remote-ssh-edit";
        #          publisher = "ms-vscode-remote";
        #          version = "0.47.2";
        #          sha256 = "1hp6gjh4xp2m1xlm1jsdzxw9d8frkiidhph6nvl24d0h8z34w49g";
        #        }
        {
          name = "cpptools";
          publisher = "ms-vscode";
          version = "1.26.1";
          sha256 = "sha256-uVE7sEO8XN3ArFpElUw25/BKyCOzF1EmZ5nHBkdoL/0=";
        }
        {
          name = "platformio-ide";
          publisher = "platformio";
          version = "3.3.4";
          sha256 = "sha256-qfNz4IYjCmCMFLtAkbGTW5xnsVT8iDnFWjrgkmr2Slk=";
        }
      ];
  })

  # Tex and LaTex
  pandoc
  mdbook

  (texlive.combine {
    inherit (texlive)
      apa6
      bibunits
      draftwatermark
      enumitem
      fontawesome5
      footnotehyper
      ifmtarg
      lualatex-math
      makecell
      microtype
      parskip
      scheme-small
      selnolig
      sourcesanspro
      tcolorbox
      threeparttable
      tikzfill
      titling
      upquote
      xifthen
      xurl
      ;

  })

]
